@@ -34,6 +34,7 @@ hyhyhy CLI
 Usage:
   hyhyhy create
   hyhyhy build
+  hyhyhy watch
   hyhyhy status
   hyhyhy help
   hyhyhy -h | --help
@@ -48,9 +49,12 @@ from __future__ import with_statement
 import os
 import sys
 import shutil
+import time
 
 from rjsmin import jsmin
 from rcssmin import cssmin
+from watchdog.events import FileSystemEventHandler
+from watchdog.observers import Observer
 
 from hyhyhy.collector import collector
 from hyhyhy.config import config
@@ -58,6 +62,11 @@ from hyhyhy.middleware import (num, prf)
 from io import open
 
 class Cli(object):
+
+    class FileChangeHandler(FileSystemEventHandler):
+        def on_any_event(self, event):
+            Cli().build()
+
     def build(self):
         if os.path.exists(u'build'):
             shutil.rmtree(u'build')
@@ -98,6 +107,22 @@ class Cli(object):
         print prf(u'OK'), u'Saved in', config.settings.get(u'core', u'build'), u'->', config.settings.get(u'head', u'title')
 
 
+    def watch(self):
+        self.build()
+        event_handler = self.FileChangeHandler()
+        observer = Observer()
+        for path in [u'assets', u'sections', config.file]:
+            observer.schedule(event_handler, path, recursive=True)
+        observer.start()
+
+        try:
+            while True:
+                time.sleep(1)
+        except KeyboardInterrupt:
+            observer.stop()
+
+        observer.join()
+
     def create(self):
         if not os.path.exists(u'assets'):
             shutil.copytree(config.path[0] + u'assets', u'assets')
@@ -133,6 +158,8 @@ def main():
 
     if len(sys.argv) == 2 and sys.argv[1] == u'build':
         cli.build()
+    elif len(sys.argv) == 2 and sys.argv[1] == u'watch':
+        cli.watch()
     elif len(sys.argv) == 2 and sys.argv[1] == u'create':
         cli.create()
     elif len(sys.argv) == 2 and sys.argv[1] == u'status':
